@@ -18,6 +18,9 @@ class ModelField:
     def get_resolver(self, entity_class):
         return lambda context, instance: getattr(instance, self.name, None)
 
+    def get_django_model_field(self, model_class):
+        return get_field_by_name(model_class, self.name)
+
 
 class ComputedField:
     def __init__(self, name, graphene_type):
@@ -41,3 +44,10 @@ class AllModelFields:
 
     def field_is_excluded(self, field):
         return field.name in self.exclude_fields
+
+    def generate_model_fields(self, model_class):
+        return {
+            field.name: ModelField(field.name)
+            for field in model_class._meta.get_fields()
+            if field.name not in self.exclude_fields
+        }
