@@ -51,7 +51,8 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 graphene_type = DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[type_name]
                 arg = registry.get_or_create_type(
-                    Types.WHERE_PREDICATE_INPUT_TYPE, django_field_type_name=type_name
+                    Types.WHERE_PREDICATE_INPUT_TYPE,
+                    graphene_type=graphene_type,
                 )
                 aggregate_basic_type_attrs[field_name] = graphene_type(
                     args={"having": arg()}
