@@ -1,6 +1,6 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
 from graphene import List, InputObjectType, Boolean, Field
-from ...mappings import Types
+from ...mappings import Types, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
 
 
 class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
@@ -59,8 +59,12 @@ class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
                     },
                 )()
             else:
+                graphene_type = model_field.get_graphene_type(
+                    model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                )
                 where_input_type_attrs[field_name] = registry.get_or_create_type(
-                    Types.WHERE_PREDICATE_INPUT_TYPE, django_field_type_name=type_name
+                    Types.WHERE_PREDICATE_INPUT_TYPE,
+                    graphene_type=graphene_type,
                 )()
 
         # These fields are always the same, they just recursively reference the
