@@ -6,13 +6,12 @@ from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
 class WherePredicate(AbstractTypeBuilder):
     @classmethod
     def cache_key(cls, type_key, **kwargs):
-        django_field_type_name = kwargs["django_field_type_name"]
-        return DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[django_field_type_name].__name__
+        graphene_type = kwargs["graphene_type"]
+        return graphene_type.__name__
 
     @staticmethod
     def make(registry, **kwargs):
-        django_field_type_name = kwargs["django_field_type_name"]
-        graphene_type = DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[django_field_type_name]
+        graphene_type = kwargs["graphene_type"]
         return type(
             "WherePredicate{}".format(graphene_type.__name__),
             (InputObjectType,),
